<?php
/*
Plugin Name: Site Vital Monitoring by DREAMHIVE
Author: DREAMHIVE
Plugin URI: http://www.dreamhive.co.jp/services/
Description: Site Vital Monitoring can monitoring your site vital easily.
Version: 0.2.0
*/

if ( ! defined( 'ABSPATH' ) ) exit;

new DHSiteVitalMonitoring();

class DHSiteVitalMonitoring {
	public function __construct() {
		//プラグインを有効化した時にWP-Cronスケジュールを登録
		if( function_exists('register_activation_hook') ) {
		    register_activation_hook( __FILE__, array(&$this, 'activationHook') );
		}

		//プラグインの停止時にWP-Cronスケジュールを削除
		if( function_exists('register_deactivation_hook') ) {
		    register_deactivation_hook ( __FILE__, array(&$this, 'deactivationHook') );
		}

		//プラグインの削除時にサーバーのステータスを変更する
		if( function_exists('register_uninstall_hook') ) {
		    register_uninstall_hook ( __FILE__, array(&$this, 'uninstallHook') );
		}

		add_filter( 'cron_schedules', array(&$this, 'addCustomCronIntervals'), 10, 1 );
		add_action( 'dh_site_vital_monitoring_cron', array($this, 'sendSignal'), 10, 1 );
	}

	// WordPressにカスタムcron intervalを追加する
	public function addCustomCronIntervals( $schedules ) {
		// $schedules stores all recurrence schedules within WordPress
		$schedules['dh_site_vital_monitoring_cron_interval'] = array(
			'interval'	=> 600,	// Number of seconds, 600 in 10 minutes
			'display'	=> '10分ごと'
		);

		// Return our newly added schedule to be merged into the others
		return (array)$schedules; 
	}

	//サーバーにシグナルを送る関数
	public function sendSignal( $status = 1 ) {
		$home_url = home_url();
		$admin_email = get_option('admin_email');
	    @file_get_contents("https://lab.dreamhive.co.jp/wp_monitoring/log?url={$home_url}&email={$admin_email}&status={$status}");
	}

	//プラグインの有効化時に実行する関数
	public function activationHook() {
	    //WP-Cronのイベントが未登録なら登録する
	    if( ! wp_next_scheduled('dh_site_vital_monitoring_cron') ){
	        wp_schedule_event(time(), 'dh_site_vital_monitoring_cron_interval', 'dh_site_vital_monitoring_cron');
	    }
	    $this->sendSignal();
	}

	//プラグインの停止時に実行する関数
	public function deactivationHook() {
		//WP-Cronのフックを削除
	    wp_clear_scheduled_hook('dh_site_vital_monitoring_cron');
	    $this->sendSignal(0);
	}

	//プラグインの削除時に実行する関数
	public function uninstallHook() {
	    $this->sendSignal(-1);
	}
}
